@@ -3,20 +3,20 @@ use std::{iter::Rev, rc::Rc, vec::IntoIter};
 use swc_common::{comments::Comment, BytePos};
 
 #[derive(Clone)]
-pub struct BufferedComment {
+pub(crate) struct BufferedComment {
     pub kind: BufferedCommentKind,
     pub pos: BytePos,
     pub comment: Comment,
 }
 
 #[derive(Clone)]
-pub enum BufferedCommentKind {
+pub(crate) enum BufferedCommentKind {
     Leading,
     Trailing,
 }
 
 #[derive(Clone)]
-pub struct CommentsBuffer {
+pub(crate) struct CommentsBuffer {
     comments: OneDirectionalList<BufferedComment>,
     pending_leading: OneDirectionalList<Comment>,
 }
