@@ -346,10 +346,15 @@ pub struct Context {
     in_cond_expr: bool,
     is_direct_child_of_cond: bool,
 
+    in_class: bool,
+
     in_function: bool,
 
     in_arrow_function: bool,
     is_direct_child_of_braceless_arrow_function: bool,
+    /// This indicates current scope or the scope out of arrow function is
+    /// function declaration or function expression or not.
+    inside_non_arrow_function_scope: bool,
 
     in_parameters: bool,
 
